/**
 * The MIT License
 *
 * Copyright (c) 2013 saka-en, http://www.saka-en.com/
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package
{
	import flash.events.Event;
	import flash.events.FocusEvent;
	import flash.events.KeyboardEvent;
	import flash.events.MouseEvent;
	import flash.system.IME;

	import mx.controls.TextInput;
	import mx.formatters.NumberFormatter;

	/**
	 * TextInput for Numeric input.
	 */
	public class NumericTextInput extends TextInput
	{
		/**
		 * コンストラクタ
		 */
		public function NumericTextInput()
		{
			super();
			// 入力キーの制御
			this.restrict = "^a-z\A-Z\-\u0009";
			// テキストを選択状態に設定
			var firstClickFlg:Boolean = true;
			this.addEventListener(MouseEvent.CLICK, function(event:Event):void {
				if ( event.currentTarget.text != "" && event.currentTarget.text != undefined ) {
					// 初回のみ選択状態を作る
					if ( firstClickFlg )
						event.currentTarget.setSelection(0, event.currentTarget.length);
					firstClickFlg = false;
				}
			});
		}

		/**
		 * 小数点以下の表示設定
		 */
		private var _precision:int = 0;

		public function set precision(precision:int):void {
			this._precision = precision;
		}

		public function get precision():int {
			return this._precision;
		}

		/**
		 *  @private
		 *  Gets called by internal field so we draw a focus rect around us.
		 */
		override protected function focusInHandler(event:FocusEvent):void {
			super.focusInHandler(event);
			// カンマ区切りを解除
			if ( event.currentTarget.text != "" )
				event.currentTarget.text = Number(this.text.replace(new RegExp(",", "g"), "")).toString();
			// テキストを選択状態に設定
			if ( event.currentTarget.text != "" && event.currentTarget.text != undefined )
				event.currentTarget.setSelection(0, event.currentTarget.length);
		}

		/**
		 *  @private
		 */
		override protected function keyDownHandler(event:KeyboardEvent):void {
			super.keyDownHandler(event);
			this.imeMode = "ALPHANUMERIC_HALF";
			IME.enabled = false;
		}

		/**
		 *  @private
		 *  Gets called by internal field so we remove focus rect.
		 */
		override protected function focusOutHandler(event:FocusEvent):void {
			super.focusOutHandler(event);
			if ( event.currentTarget.text != "" ) {
				var nf:NumberFormatter = new NumberFormatter();
				nf.useThousandsSeparator = true;
				// 小数点以下の設定
				nf.precision = _precision;
				// マイナスの表示許可
				nf.useNegativeSign = true;
				event.currentTarget.text = nf.format(event.currentTarget.text);
			}
		}
	}
}