/**
 * The MIT License
 *
 * Copyright (c) 2013 saka-en, http://www.saka-en.com/
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package
{
	import flash.events.Event;
	import flash.events.FocusEvent;

	import mx.containers.HBox;
	import mx.controls.AdvancedDataGrid;
	import mx.controls.dataGridClasses.DataGridListData;
	import mx.controls.listClasses.BaseListData;
	import mx.controls.listClasses.IDropInListItemRenderer;
	import mx.controls.listClasses.IListItemRenderer;
	import mx.managers.IFocusManager;
	import mx.managers.IFocusManagerComponent;

	/**
	 * 数値入力レンダラー
	 */
	public class NumericTextInputRenderer extends HBox implements IListItemRenderer, IDropInListItemRenderer, IFocusManagerComponent
	{
		/**
		 * コンストラクタ
		 */
		public function NumericTextInputRenderer()
		{
			super();
		}

		/**
		 * NumericTextInput
		 */
		private var textInput:NumericTextInput = null;

		/**
		 * listData
		 */
		private var _listData:BaseListData;

		[Bindable("dataChange")]
		[Inspectable(environment="none")]
		public function get listData():BaseListData {
			return this._listData;
		}

		public function set listData(value:BaseListData):void {
			this._listData = value;
		}

		/**
		 * TextInputのID
		 */
		private var _tid:String = "";

		public function get tid():String {
			return this._tid;
		}
		public function set tid(tid:String):void {
			this._tid = tid;
		}

		/**
		 *  @private
		 *  Create components that are children of this Container.
		 */
		override protected function createChildren():void
		{
			super.createChildren();

			this.textInput = new NumericTextInput();
			this.textInput.width = 100;
			this.textInput.maxChars = 16;
			this.textInput.imeMode = "ALPHANUMERIC_HALF";
			this.textInput.precision = 0;	// 小数点以下の表示桁数
			this.id = _tid;
			this.textInput.addEventListener(FocusEvent.FOCUS_OUT, function(event:FocusEvent):void {
				if ( event.currentTarget.text == "" )
					return;
				var dgOwner:AdvancedDataGrid = event.currentTarget.owner.owner as AdvancedDataGrid;
				var idx:int = dgOwner.selectedIndex;
				data[DataGridListData(_listData).dataField] = event.currentTarget.text;
				dgOwner.dataProvider[idx][DataGridListData(_listData).dataField] = event.currentTarget.text;
				dgOwner.validateNow();
				dgOwner.dispatchEvent(event);
			});
			addChild(this.textInput);
		}

		/**
		 * 表示処理
		 */
		override protected function commitProperties():void
		{
			super.commitProperties();
			if ( data != null )
				this.textInput.text = data[DataGridListData(_listData).dataField];
		}

		/**
		 * フォーカスセット
		 */
		override public function setFocus():void
		{
			var fm:IFocusManager = this.focusManager;
			if (IFocusManagerComponent(this.textInput) != fm.getFocus())
				fm.setFocus(IFocusManagerComponent(this.textInput));
		}
	}
}
